@@ -214,9 +214,9 @@ service::instance::~instance()
 
 void service::keyclone::splice(keyclone *trunk)
 {
-    parent = trunk;
-    if(parent)
-        enlistTail(&trunk->child);
+    Parent = trunk;
+    if(Parent)
+        enlistTail(&trunk->Child);
 }
 
 service::service(const char *name, size_t s) :
@@ -239,7 +239,7 @@ service::~service()
 {
     // we must zap the xml tree root node, lest it try to delete it's "id"
     // or child nodes, since all was allocated from the "pager" heap.
-    memset(&root, 0, sizeof(root));
+    reset_unsafe<keynode>(root);
     memalloc::purge();
 }
 
